@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 SuperGemini Framework Management Hub
 Unified entry point for all SuperGemini operations
@@ -18,30 +18,41 @@ import difflib
 from pathlib import Path
 from typing import Dict, Callable
 
-# Add the 'setup' directory to the Python import path
-# Fix for installed package to find setup module correctly
-import os
+# Import version from SSOT
+try:
+    from .version import __version__
+except ImportError:
+    # Fallback if module structure is broken
+    __version__ = "4.0.9"
 
-# First, try to find setup in the installed package location
-package_dir = Path(__file__).parent.parent  # SuperGemini package directory
+# Add the 'setup' directory to the Python import path (modern approach)
 
-# Check if we're running from installed package or development
-if (package_dir / "setup").exists():
-    setup_dir = package_dir
-else:
-    # Fallback to site-packages location
-    import site
-    for site_dir in site.getsitepackages():
-        potential_setup = Path(site_dir) / "setup"
-        if potential_setup.exists():
-            setup_dir = Path(site_dir)
-            break
-    else:
-        # Last resort: assume setup is in the same directory as SuperGemini
-        setup_dir = package_dir
-
-# Add to sys.path
-sys.path.insert(0, str(setup_dir))
+try:
+    # Python 3.9+ preferred way
+    from importlib.resources import files, as_file
+    with as_file(files("setup")) as resource:
+        setup_dir = str(resource)
+        sys.path.insert(0, setup_dir)
+except (ImportError, ModuleNotFoundError, AttributeError):
+    # Fallback: try to locate setup relative to this file
+    try:
+        current_dir = Path(__file__).parent
+        project_root = current_dir.parent
+        setup_dir = project_root / "setup"
+        if setup_dir.exists():
+            sys.path.insert(0, str(setup_dir))
+        else:
+            # Last resort: try pkg_resources if available
+            try:
+                from pkg_resources import resource_filename
+                setup_dir = resource_filename('setup', '')
+                sys.path.insert(0, str(setup_dir))
+            except ImportError:
+                # If all else fails, setup directory should be relative to this file
+                sys.path.insert(0, str(project_root / "setup"))
+    except Exception as e:
+        print(f"Warning: Could not locate setup directory: {e}")
+        # Continue anyway, imports might still work
 
 
 # Try to import utilities from the setup package
@@ -58,7 +69,7 @@ except ImportError:
     DEFAULT_INSTALL_DIR = Path.home() / ".gemini"
     
     class Colors:
-        RED = YELLOW = GREEN = CYAN = RESET = BRIGHT = ""
+        RED = YELLOW = GREEN = CYAN = RESET = ""
 
     def display_error(msg): print(f"[ERROR] {msg}")
     def display_warning(msg): print(f"[WARN] {msg}")
@@ -110,7 +121,7 @@ Examples:
         parents=[global_parser]
     )
 
-    parser.add_argument("--version", action="store_true", help="Show version and exit")
+    parser.add_argument("--version", action="version", version=f"SuperGemini {__version__}")
 
     subparsers = parser.add_subparsers(
         dest="operation",
@@ -155,7 +166,7 @@ def get_operation_modules() -> Dict[str, str]:
 def load_operation_module(name: str):
     """Try to dynamically import an operation module"""
     try:
-        return __import__(f"setup.operations.{name}", fromlist=[name])
+        return __import__(f"setup.cli.commands.{name}", fromlist=[name])
     except ImportError as e:
         logger = get_logger()
         if logger:
@@ -215,15 +226,10 @@ def main() -> int:
         operations = register_operation_parsers(subparsers, global_parser)
         args = parser.parse_args()
 
-        # Handle --version flag
-        if hasattr(args, 'version') and args.version:
-            print("SuperGemini v3.2.0")
-            return 0
-
         # No operation provided? Show help manually unless in quiet mode
-        if not hasattr(args, 'operation') or not args.operation:
+        if not args.operation:
             if not args.quiet:
-                display_header("SuperGemini Framework v3.2.0", "Unified CLI for all operations")
+                display_header(f"SuperGemini Framework v{__version__}", "Unified CLI for all operations")
                 print(f"{Colors.CYAN}Available operations:{Colors.RESET}")
                 for op, desc in get_operation_modules().items():
                     print(f"  {op:<12} {desc}")
