@@ -3,9 +3,13 @@
 from .core import CoreComponent
 from .commands import CommandsComponent
 from .mcp import MCPComponent
+from .modes import ModesComponent
+from .mcp_docs import MCPDocsComponent
 
 __all__ = [
     'CoreComponent',
     'CommandsComponent', 
-    'MCPComponent'
+    'MCPComponent',
+    'ModesComponent',
+    'MCPDocsComponent'
 ]
\ No newline at end of file
