@@ -6,7 +6,8 @@ from typing import Dict, List, Tuple, Optional, Any
 from pathlib import Path
 import shutil
 
-from ..base.component import Component
+from ..core.base import Component
+from ..services.gemini_md import GEMINIMdService
 
 class CoreComponent(Component):
     """Core SuperGemini framework files component"""
@@ -17,26 +18,28 @@ class CoreComponent(Component):
     
     def get_metadata(self) -> Dict[str, str]:
         """Get component metadata"""
+        from .. import __version__
         return {
             "name": "core",
-            "version": "3.2.0",
+            "version": __version__,
             "description": "SuperGemini framework documentation and core files",
             "category": "core"
         }
     
     def get_metadata_modifications(self) -> Dict[str, Any]:
         """Get metadata modifications for SuperGemini"""
+        from .. import __version__
         return {
             "framework": {
-                "version": "3.2.0",
+                "version": __version__,
                 "name": "SuperGemini",
-                "description": "AI-enhanced development framework for Gemini Code",
+                "description": "AI-enhanced development framework for Gemini CLI",
                 "installation_type": "global",
                 "components": ["core"]
             },
             "supergemini": {
                 "enabled": True,
-                "version": "3.2.0",
+                "version": __version__,
                 "profile": "default",
                 "auto_update": False
             }
@@ -48,16 +51,17 @@ class CoreComponent(Component):
 
         return super()._install(config);
 
-    def _post_install(self):
+    def _post_install(self) -> bool:
         # Create or update metadata
         try:
+            from .. import __version__
             metadata_mods = self.get_metadata_modifications()
             self.settings_manager.update_metadata(metadata_mods)
             self.logger.info("Updated metadata with framework configuration")
             
             # Add component registration to metadata
             self.settings_manager.add_component_registration("core", {
-                "version": "3.2.0",
+                "version": __version__,
                 "category": "core",
                 "files_count": len(self.component_files)
             })
@@ -77,6 +81,15 @@ class CoreComponent(Component):
             dir_path = self.install_dir / dirname
             if not self.file_manager.ensure_directory(dir_path):
                 self.logger.warning(f"Could not create directory: {dir_path}")
+        
+        # Update GEMINI.md with core framework imports
+        try:
+            manager = GEMINIMdService(self.install_dir)
+            manager.add_imports(self.component_files, category="Core Framework")
+            self.logger.info("Updated GEMINI.md with core framework imports")
+        except Exception as e:
+            self.logger.warning(f"Failed to update GEMINI.md with core framework imports: {e}")
+            # Don't fail the whole installation for this
 
         return True
 
@@ -215,28 +228,10 @@ class CoreComponent(Component):
     
     def _get_source_dir(self):
         """Get source directory for framework files"""
-        # Try multiple possible locations for core files
-        current_file = Path(__file__)
-        
-        # Option 1: Development mode - relative to this file
-        dev_path = current_file.parent.parent.parent / "SuperGemini" / "Core"
-        if dev_path.exists():
-            return dev_path
-        
-        # Option 2: Installed package - look in site-packages
-        import site
-        for site_dir in site.getsitepackages():
-            installed_path = Path(site_dir) / "SuperGemini" / "Core"
-            if installed_path.exists():
-                return installed_path
-        
-        # Option 3: Same directory as package
-        package_path = current_file.parent.parent.parent / "Core"
-        if package_path.exists():
-            return package_path
-            
-        # Fallback to original path
-        return dev_path
+        # Assume we're in SuperGemini/setup/components/core.py
+        # and framework files are in SuperGemini/SuperGemini/Core/
+        project_root = Path(__file__).parent.parent.parent
+        return project_root / "SuperGemini" / "Core"
     
     def get_size_estimate(self) -> int:
         """Get estimated installation size"""
