@@ -533,10 +533,10 @@ class Validator:
             Installation commands dict
         """
         try:
-            from ..managers.config_manager import ConfigManager
-            from .. import PROJECT_ROOT
+            from ..services.config import ConfigService
+            from .. import DATA_DIR
             
-            config_manager = ConfigManager(PROJECT_ROOT / "config")
+            config_manager = ConfigService(DATA_DIR)
             requirements = config_manager.load_requirements()
             return requirements.get("installation_commands", {})
         except Exception:
@@ -650,40 +650,16 @@ class Validator:
             tool_found = False
             for tool in tool_alternatives:
                 try:
-                    # Use different command based on platform
-                    if sys.platform == "win32":
-                        # On Windows, use where command
-                        cmd = ["where", tool]
-                    else:
-                        # On Unix-like systems, use which
-                        cmd = ["which", tool]
-                    
                     result = subprocess.run(
-                        cmd,
+                        ["which" if sys.platform != "win32" else "where", tool],
                         capture_output=True,
                         text=True,
                         timeout=5,
-                        shell=False  # Don't use shell for security
+                        shell=(sys.platform == "win32")
                     )
                     if result.returncode == 0:
                         tool_found = True
                         break
-                except (subprocess.TimeoutExpired, FileNotFoundError):
-                    # Try with shell=True as fallback on Windows
-                    if sys.platform == "win32":
-                        try:
-                            result = subprocess.run(
-                                f"where {tool}",
-                                capture_output=True,
-                                text=True,
-                                timeout=5,
-                                shell=True
-                            )
-                            if result.returncode == 0:
-                                tool_found = True
-                                break
-                        except Exception:
-                            continue
                 except Exception:
                     continue
             
