@@ -6,6 +6,7 @@ Cross-platform console UI with colors and progress indication
 import sys
 import time
 import shutil
+import getpass
 from typing import List, Optional, Any, Dict, Union
 from enum import Enum
 
@@ -189,12 +190,13 @@ class Menu:
         else:
             print(f"\n{Colors.BLUE}Enter your choice (1-{len(self.options)}):{Colors.RESET}")
         
-        while True:
+        max_attempts = 10  # Prevent infinite recursion
+        attempt = 0
+        
+        while attempt < max_attempts:
+            attempt += 1
             try:
                 user_input = input("> ").strip().lower()
-            except EOFError:
-                print(f"\n{Colors.RED}[✗] EOF when reading a line - using default selection{Colors.RESET}")
-                return [] if self.multi_select else -1
                 
                 if self.multi_select:
                     if user_input == 'all':
@@ -225,12 +227,19 @@ class Menu:
                     else:
                         print(f"{Colors.RED}Please enter a valid number.{Colors.RESET}")
                         
-            except (ValueError, KeyboardInterrupt) as e:
+            except (ValueError, KeyboardInterrupt, EOFError) as e:
                 if isinstance(e, KeyboardInterrupt):
                     print(f"\n{Colors.YELLOW}Operation cancelled.{Colors.RESET}")
                     return [] if self.multi_select else -1
+                elif isinstance(e, EOFError):
+                    print(f"\n{Colors.YELLOW}EOF detected, cancelling operation.{Colors.RESET}")
+                    return [] if self.multi_select else -1
                 else:
                     print(f"{Colors.RED}Invalid input: {e}{Colors.RESET}")
+        
+        # If we reach here, too many failed attempts
+        print(f"\n{Colors.RED}Too many invalid attempts. Cancelling operation.{Colors.RESET}")
+        return [] if self.multi_select else -1
 
 
 def confirm(message: str, default: bool = True) -> bool:
@@ -247,7 +256,11 @@ def confirm(message: str, default: bool = True) -> bool:
     suffix = "[Y/n]" if default else "[y/N]"
     print(f"{Colors.BLUE}{message} {suffix}{Colors.RESET}")
     
-    while True:
+    max_attempts = 10  # Prevent infinite recursion
+    attempt = 0
+    
+    while attempt < max_attempts:
+        attempt += 1
         try:
             response = input("> ").strip().lower()
             
@@ -260,9 +273,13 @@ def confirm(message: str, default: bool = True) -> bool:
             else:
                 print(f"{Colors.RED}Please enter 'y' or 'n' (or press Enter for default).{Colors.RESET}")
                 
-        except KeyboardInterrupt:
+        except (KeyboardInterrupt, EOFError):
             print(f"\n{Colors.YELLOW}Operation cancelled.{Colors.RESET}")
             return False
+    
+    # If we reach here, too many failed attempts
+    print(f"\n{Colors.RED}Too many invalid attempts. Using default: {default}{Colors.RESET}")
+    return default
 
 
 def display_header(title: str, subtitle: str = '') -> None:
@@ -342,6 +359,43 @@ def display_table(headers: List[str], rows: List[List[str]], title: str = '') ->
     print()
 
 
+def prompt_api_key(service_name: str, env_var_name: str) -> Optional[str]:
+    """
+    Prompt for API key with security and UX best practices
+    
+    Args:
+        service_name: Human-readable service name (e.g., "Magic", "Morphllm")
+        env_var_name: Environment variable name (e.g., "TWENTYFIRST_API_KEY")
+        
+    Returns:
+        API key string if provided, None if skipped
+    """
+    print(f"{Colors.BLUE}[API KEY] {service_name} requires: {Colors.BRIGHT}{env_var_name}{Colors.RESET}")
+    print(f"{Colors.WHITE}Visit the service documentation to obtain your API key{Colors.RESET}")
+    print(f"{Colors.YELLOW}Press Enter to skip (you can set this manually later){Colors.RESET}")
+    
+    try:
+        # Use getpass for hidden input
+        api_key = getpass.getpass(f"Enter {env_var_name}: ").strip()
+        
+        if not api_key:
+            print(f"{Colors.YELLOW}[SKIPPED] {env_var_name} - set manually later{Colors.RESET}")
+            return None
+        
+        # Basic validation (non-empty, reasonable length)
+        if len(api_key) < 10:
+            print(f"{Colors.RED}[WARNING] API key seems too short. Continue anyway? (y/N){Colors.RESET}")
+            if not confirm("", default=False):
+                return None
+        
+        print(f"{Colors.GREEN}[✓] {env_var_name} configured{Colors.RESET}")
+        return api_key
+        
+    except KeyboardInterrupt:
+        print(f"\n{Colors.YELLOW}[SKIPPED] {env_var_name}{Colors.RESET}")
+        return None
+
+
 def wait_for_key(message: str = "Press Enter to continue...") -> None:
     """Wait for user to press a key"""
     try:
